import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { UnknownValuePlotting, UnknownValuePlotting_$type } from './UnknownValuePlotting';
import { IgxHorizontalAnchoredCategorySeriesComponent } from './igx-horizontal-anchored-category-series-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxCategorySeriesComponent } from './igx-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { AreaSeries } from "./AreaSeries";
import { ensureEnum } from "./componentUtil";
/**
 * Represents a IgxDataChartComponent area series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*/
export const IgxAreaSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }];
export class IgxAreaSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new AreaSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets whether the current series shows an area or line shape.
        */
    get isAreaOrLine() {
        return this.i.ci;
    }
    /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
    get unknownValuePlotting() {
        return this.i.unknownValuePlotting;
    }
    set unknownValuePlotting(v) {
        this.i.unknownValuePlotting = ensureEnum(UnknownValuePlotting_$type, v);
    }
}
IgxAreaSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-area-series',
                template: ``,
                providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxAreaSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxAreaSeriesComponent.ctorParameters = () => [];
IgxAreaSeriesComponent.propDecorators = {
    "unknownValuePlotting": [{ type: Input },],
};
//# sourceMappingURL=igx-area-series-component.js.map