import { HighlightingInfo } from './igx-highlighting-info';
import { AssigningCategoryStyleEventArgsBase as AssigningCategoryStyleEventArgsBase_internal } from "./AssigningCategoryStyleEventArgsBase";
/**
 * Represents event arguments base class for the AssigningCategoryStyleEventArgsBase
*/
export declare abstract class AssigningCategoryStyleEventArgsBase {
    protected createImplementation(): AssigningCategoryStyleEventArgsBase_internal;
    protected _implementation: any;
    readonly i: AssigningCategoryStyleEventArgsBase_internal;
    private onImplementationCreated();
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Gets the start index
    */
    readonly startIndex: number;
    /**
     * Gets the end index
    */
    readonly endIndex: number;
    /**
     * Gets the start date
    */
    readonly startDate: Date;
    /**
     * Gets the end date
    */
    readonly endDate: Date;
    /**
     * Gets a function that will return the items associated with this event.
    */
    readonly getItems: (orderedStartIndex: number, orderedEndIndex: number) => any[];
    /**
     * Gets or sets fill brush to use for the current item.
    */
    fill: string;
    /**
     * Gets or sets stroke to use for the current item.
    */
    stroke: string;
    /**
     * Gets or sets opacity to use for the current item.
    */
    opacity: number;
    /**
     * Gets or sets highlighting info
    */
    highlightingInfo: HighlightingInfo;
    /**
     * Gets the max highlighting progress from all series.
    */
    readonly maxAllSeriesHighlightingProgress: number;
    /**
     * Gets the sum of highlighting progress from all series.
    */
    readonly sumAllSeriesHighlightingProgress: number;
    /**
     * Gets or sets if highlighting was handled by this event handler, and whether internal highlighting logic should be skipped.
    */
    highlightingHandled: boolean;
    /**
     * Gets if this event has a valid date range
    */
    readonly hasDateRange: boolean;
    /**
     * Gets if the current shape is identified as a negative shape if this series supports discrete negative shapes.
    */
    readonly isNegativeShape: boolean;
    /**
     * Gets if the current event is being raised for the thumbnail image.
    */
    readonly isThumbnail: boolean;
}
