import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxAxisComponent } from './igx-axis-component';
import { CategoryXAxis } from "./CategoryXAxis";
/**
 * Represents a IgxDataChartComponent category X axis.
*/
export const IgxCategoryXAxisComponent_PROVIDERS = [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryXAxisComponent) }];
export class IgxCategoryXAxisComponent extends IgxCategoryAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryXAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        *
        * `interval` determines how often to show a label, tickmark, and/or gridline along the x-axis.  Set this property to _n_ to display a label every _nth_ item.
        *
        * ```html
        * <igx-data-chart [dataSource]="data">
        *   <igx-category-x-axis #xAxis
        *     label="label"
        *     interval="3">
        *   </igx-category-x-axis>
        *   <igx-numeric-y-axis #yAxis>
        *   </igx-numeric-y-axis>
        *
        *   <igx-column-series
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     valueMemberPath="value">
        *   </igx-column-series>
        * </igx-data-chart>
        * ```
        */
    get interval() {
        return this.i.ki;
    }
    set interval(v) {
        this.i.ki = +v;
    }
    /**
         * Gets the effective value for the current Interval.
        */
    get actualInterval() {
        return this.i.kd;
    }
    /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        *
        * `minorInterval` determines how often to show a minor gridline along the x-axis.  This property is relevant only when the displayed series is a type with grouping, like column series.
        *
        * `minorInterval` is expressed as a number between 0 and 1, representing the frequency of the interval.  To display minor gridlines representing 10ths of an item width, set `minorInterval` to 0.1.
        *
        * ```html
        * <igx-data-chart [dataSource]="data">
        *   <igx-category-x-axis #xAxis
        *     label="label"
        *     minorInterval="0.1"
        *     minorStroke="green"
        *     minorStrokeThickness="1">
        *   </igx-category-x-axis>
        *   <igx-numeric-y-axis #yAxis>
        *   </igx-numeric-y-axis>
        *
        *   <igx-column-series
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     valueMemberPath="value">
        *   </igx-column-series>
        * </igx-data-chart>
        * ```
        */
    get minorInterval() {
        return this.i.kj;
    }
    set minorInterval(v) {
        this.i.kj = +v;
    }
    /**
         * Gets the effective value for the current MinorInterval.
        */
    get actualMinorInterval() {
        return this.i.ke;
    }
    /**
         * Scrolls the specified item into view.
        
        * @param item  * Data item to scroll into view
        */
    scrollIntoView(item) {
        this.i.ks(item);
    }
    scrollRangeIntoView(minimum, maximum) {
        this.i.kt(minimum, maximum);
    }
}
IgxCategoryXAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-x-axis',
                template: ``,
                providers: [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryXAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryXAxisComponent.ctorParameters = () => [];
IgxCategoryXAxisComponent.propDecorators = {
    "interval": [{ type: Input },],
    "minorInterval": [{ type: Input },],
};
//# sourceMappingURL=igx-category-x-axis-component.js.map