/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Injector, ComponentFactoryResolver, Component, Renderer2, ViewChild, ContentChildren, QueryList, Inject, Input, forwardRef, NgZone, ChangeDetectionStrategy, ViewContainerRef } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { IgxAxisComponent } from './igx-axis-component';
import { IgxSeriesComponent } from './igx-series-component';
import { GridMode, GridMode_$type } from './GridMode';
import { IgxSeriesViewerComponent } from './igx-series-viewer-component';
import { AngularRenderer, AngularWrapper } from './angular-renderer';
import { TypeRegistrar } from './type';
import { XamDataChart } from './XamDataChart';
import { CollectionAdapter, brushToString, stringToBrush, fromBrushCollection, toBrushCollection, ensureBool, ensureEnum } from './componentUtil';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataContext } from './igx-data-context';
import { SeriesCollection } from './igx-series-collection';
import { NotifyCollectionChangedAction } from './NotifyCollectionChangedAction';
import { AxisCollection } from './igx-axis-collection';
export const IgxDataChartComponent_PROVIDERS = [{ provide: IgxSeriesViewerComponent, useExisting: forwardRef(() => IgxDataChartComponent) }];
/**
 * Represents a chart area containing axes, series, an optional legend and other hosted content.
*/
export class IgxDataChartComponent extends IgxSeriesViewerComponent {
    constructor(_renderer, _document, _elRef, _ngZone, _componentFactoryResolver, _injector) {
        super();
        this._renderer = _renderer;
        this._document = _document;
        this._elRef = _elRef;
        this._ngZone = _ngZone;
        this._componentFactoryResolver = _componentFactoryResolver;
        this._injector = _injector;
        /**
             * The series actually present in the chart. Do not directly modify this array.
             * This array's contents can be modified by causing Angular to reproject the child content.
             * Or adding and removing series from the manual series collection on the series property.
             */
        this.actualSeries = [];
        /**
             * The axes actually present in the chart. Do not directly modify this array.
             * This array's contents can be modified by causing Angular to reproject the child content.
             * Or adding and removing axes from the manual axes collection on the axes property.
             */
        this.actualAxes = [];
        this._series = null;
        this._axes = null;
        this._dataSource = null;
        this._axesAdapter = null;
        this._seriesAdapter = null;
        this._defaultTooltips = null;
        this._zoneRunner = (act) => this._ngZone.run(act);
        this._container = _renderer.createElement("div");
        _renderer.appendChild(_elRef.element.nativeElement, this._container);
        _renderer.setStyle(this._container, "display", "block");
        _renderer.setStyle(this._container, "width", "100%");
        _renderer.setStyle(this._container, "height", "100%");
        var root;
        root = this._container;
        if (this._container.nativeElement != null) {
            root = this._container.nativeElement;
        }
        var ren = new AngularRenderer(root, this._renderer, this._document, this._ngZone, true, DataChartStylingDefaults);
        this._wrapper = ren;
        var chart = this.i;
        this._chart = chart;
        chart.provideContainer(ren);
        ren.addSizeWatcher(() => {
            this._chart.notifyContainerResized();
        });
    }
    set height(value) {
        this._height = value;
        this._renderer.setStyle(this._elRef.element.nativeElement, "height", value);
        this._chart.notifyContainerResized();
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        this._renderer.setStyle(this._elRef.element.nativeElement, "width", value);
        this._chart.notifyContainerResized();
    }
    get width() {
        return this._width;
    }
    /**
         * A collection or manually added series for the chart.
        */
    get series() {
        if (this._series === null) {
            let coll = new SeriesCollection();
            let inner = coll._innerColl;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._seriesAdapter.addManualItem(e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._seriesAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._seriesAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._seriesAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._seriesAdapter.clearManualItems();
                        break;
                }
            });
            this._series = coll;
        }
        return this._series;
    }
    /**
         * A collection or manually added axes for the chart.
        */
    get axes() {
        if (this._axes === null) {
            let coll = new AxisCollection();
            let inner = coll._innerColl;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._axesAdapter.addManualItem(e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._axesAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._axesAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._axesAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._axesAdapter.clearManualItems();
                        break;
                }
            });
            this._axes = coll;
        }
        return this._axes;
    }
    ngOnDestroy() {
        this._chart.destroy();
        this._wrapper.destroy();
    }
    createImplementation() {
        return new XamDataChart();
    }
    set dataSource(value) {
        this._dataSource = value;
        this.bindData();
    }
    get dataSource() {
        return this._dataSource;
    }
    bindData() {
        //console.log("binding data: " + this._dataSource);
        if (this.actualAxes && this.actualAxes.length > 0) {
            var currAxes = this.actualAxes;
            for (var i = 0; i < currAxes.length; i++) {
                currAxes[i].provideData(this._dataSource);
            }
        }
        if (this.actualSeries && this.actualSeries.length > 0) {
            var currSeries = this.actualSeries;
            for (var i = 0; i < currSeries.length; i++) {
                currSeries[i].provideData(this._dataSource);
            }
        }
    }
    ngAfterContentInit() {
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            let c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            let cf = this._componentFactoryResolver.resolveComponentFactory(c);
            let cr = this._dynamicContent.createComponent(cf);
            //let cr = cf.create(this._injector);
            this._defaultTooltips = cr;
            cr.instance.onContentReady.subscribe(() => {
                this._onDefaultTooltipsReady(cr);
            });
            //this._container.appendChild(cr.location.nativeElement);
        }
        this._axesAdapter = new CollectionAdapter(this.contentAxes, this.i.axes, this.actualAxes, (c) => c.i, (i) => { i._provideRenderer(this._wrapper); i.provideData(this._dataSource); }, (i) => { i._provideRenderer(null); i.provideData(null); });
        this._seriesAdapter = new CollectionAdapter(this.contentSeries, this.i.series, this.actualSeries, (c) => c.i, (i) => {
            i.owner = this;
            i._provideRenderer(this._dataSource);
            i.provideData(this._dataSource);
            //i.bindAxes(this.axes);
            this._ensureDefaultTooltip(i);
            this._ensureTooltipCreated(i);
        }, (i) => { i._provideRenderer(null); i.provideData(null); });
        this.i.notifyContainerResized();
    }
    _ensureTooltipCreated(series) {
        series._ensureTooltipCreated(() => this.createTooltip(), (ele) => {
            let wrapper = new AngularWrapper(ele, this._renderer, this._ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    }
    _ensureDefaultTooltip(series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    }
    _onDefaultTooltipsReady(cr) {
        if (this.actualSeries && this.actualSeries.length > 0) {
            var currSeries = this.actualSeries;
            for (var i = 0; i < currSeries.length; i++) {
                if (currSeries[i].showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries[i]);
                }
            }
        }
    }
    createTooltip() {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        let t = TypeRegistrar.get("IgxTooltipContainerComponent");
        let cf = this._componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this._injector);
        let cr = this._elRef.createComponent(cf);
        let ele = cr.location.nativeElement;
        let self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                let ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self._container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self._container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets whether to use a square aspect ratio for the chart. This is locked to true for polar and radial charts.
        */
    get isSquare() {
        return this.i.nm;
    }
    set isSquare(v) {
        this.i.nm = ensureBool(v);
    }
    /**
         * A number between 0 and 1 determining the scale of the horizontal zoom.
         * This property is effectively a shortcut to the Width of the WindowRect property.
        */
    get windowScaleHorizontal() {
        return this.i.n5;
    }
    set windowScaleHorizontal(v) {
        this.i.n5 = +v;
    }
    /**
         * A number between 0 and 1 determining the scale of the vertical zoom.
         * This property is effectively a shortcut to the Height of the WindowRect property.
        */
    get windowScaleVertical() {
        return this.i.n6;
    }
    set windowScaleVertical(v) {
        this.i.n6 = +v;
    }
    /**
         * A number between 0 and 1 determining the scale of the horizontal zoom.
         * This property is effectively a shortcut to the Width of the ActualWindowRect property.
        */
    get actualWindowScaleHorizontal() {
        return this.i.nx;
    }
    /**
         * A number between 0 and 1 determining the scale of the vertical zoom.
         * This property is effectively a shortcut to the Height of the ActualWindowRect property.
        */
    get actualWindowScaleVertical() {
        return this.i.ny;
    }
    /**
         * Gets or sets horizontal zoomability of the current control
        */
    get isHorizontalZoomEnabled() {
        return this.i.nl;
    }
    set isHorizontalZoomEnabled(v) {
        this.i.nl = ensureBool(v);
    }
    /**
         * Gets or sets vertical zoomability of the current control
        */
    get isVerticalZoomEnabled() {
        return this.i.nn;
    }
    set isVerticalZoomEnabled(v) {
        this.i.nn = ensureBool(v);
    }
    /**
         * Gets or sets how grid lines are rendered in relation to series.
        */
    get gridMode() {
        return this.i.na;
    }
    set gridMode(v) {
        this.i.na = ensureEnum(GridMode_$type, v);
    }
    /**
         * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
        */
    get alignsGridLinesToPixels() {
        return this.i.nh;
    }
    set alignsGridLinesToPixels(v) {
        this.i.nh = ensureBool(v);
    }
    /**
         * Gets or sets the palette of brushes to use for coloring the chart series.
        */
    get brushes() {
        return fromBrushCollection(this.i.m3);
    }
    set brushes(v) {
        this.i.m3 = toBrushCollection(v);
    }
    /**
         * Gets or sets the MarkerBrushes property.
         * The brushes property defines the palette from which automatically assigned series brushes are selected.
        */
    get markerBrushes() {
        return fromBrushCollection(this.i.m4);
    }
    set markerBrushes(v) {
        this.i.m4 = toBrushCollection(v);
    }
    /**
         * Gets or sets the palette of brushes to use for outlines on the chart series.
        */
    get outlines() {
        return fromBrushCollection(this.i.m6);
    }
    set outlines(v) {
        this.i.m6 = toBrushCollection(v);
    }
    /**
         * Gets or sets the MarkerOutlines property.
         * The brushes property defines the palette from which automatically assigned series brushes are selected.
        */
    get markerOutlines() {
        return fromBrushCollection(this.i.m5);
    }
    set markerOutlines(v) {
        this.i.m5 = toBrushCollection(v);
    }
    /**
         * Gets or sets the DefaultAxisStroke property.
         * The DefaultAxisStroke property defines the brush which is used by the axes when no Axis.Stroke is set.
        */
    get defaultAxisStroke() {
        return brushToString(this.i.pi);
    }
    set defaultAxisStroke(v) {
        this.i.pi = stringToBrush(v);
    }
    /**
         * Gets or sets the DefaultAxisMajorStroke property.
         * The DefaultAxisMajorStroke property defines the brush which is used by the axes when no Axis.MajorStroke is set.
        */
    get defaultAxisMajorStroke() {
        return brushToString(this.i.pg);
    }
    set defaultAxisMajorStroke(v) {
        this.i.pg = stringToBrush(v);
    }
    /**
         * Gets or sets the DefaultAxisMinorStroke property.
         * The DefaultAxisMinorStroke property defines the brush which is used by the axes when no Axis.MinorStroke is set.
        */
    get defaultAxisMinorStroke() {
        return brushToString(this.i.ph);
    }
    set defaultAxisMinorStroke(v) {
        this.i.ph = stringToBrush(v);
    }
    /**
         * Margin applied to the left of the plot area.
        */
    get plotAreaMarginLeft() {
        return this.i.n2;
    }
    set plotAreaMarginLeft(v) {
        this.i.n2 = +v;
    }
    /**
         * Margin applied above the plot area.
        */
    get plotAreaMarginTop() {
        return this.i.n4;
    }
    set plotAreaMarginTop(v) {
        this.i.n4 = +v;
    }
    /**
         * Margin applied to the right of the plot area.
        */
    get plotAreaMarginRight() {
        return this.i.n3;
    }
    set plotAreaMarginRight(v) {
        this.i.n3 = +v;
    }
    /**
         * Margin applied below the plot area.
        */
    get plotAreaMarginBottom() {
        return this.i.n1;
    }
    set plotAreaMarginBottom(v) {
        this.i.n1 = +v;
    }
    /**
         * Notifies the chart that the CSS styles in effect have been updated.
        
        */
    styleUpdated() {
        this.i.oy();
    }
    /**
         * Export serialized visual data.
        
        */
    exportSerializedVisualData() {
        let iv = this.i.og();
        return (iv);
    }
}
IgxDataChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-data-chart',
                template: `<ng-container #dynamicContent></ng-container>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: IgxSeriesViewerComponent, useExisting: forwardRef(() => IgxDataChartComponent) }],
                styles: [`
		:host {
			display: block;
		}
	`]
            },] },
];
/** @nocollapse */
IgxDataChartComponent.ctorParameters = () => [
    { type: Renderer2, },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: ViewContainerRef, },
    { type: NgZone, },
    { type: ComponentFactoryResolver, },
    { type: Injector, },
];
IgxDataChartComponent.propDecorators = {
    "contentAxes": [{ type: ContentChildren, args: [IgxAxisComponent,] },],
    "contentSeries": [{ type: ContentChildren, args: [IgxSeriesComponent,] },],
    "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
    "height": [{ type: Input },],
    "width": [{ type: Input },],
    "dataSource": [{ type: Input },],
    "isSquare": [{ type: Input },],
    "windowScaleHorizontal": [{ type: Input },],
    "windowScaleVertical": [{ type: Input },],
    "isHorizontalZoomEnabled": [{ type: Input },],
    "isVerticalZoomEnabled": [{ type: Input },],
    "gridMode": [{ type: Input },],
    "alignsGridLinesToPixels": [{ type: Input },],
    "brushes": [{ type: Input },],
    "markerBrushes": [{ type: Input },],
    "outlines": [{ type: Input },],
    "markerOutlines": [{ type: Input },],
    "defaultAxisStroke": [{ type: Input },],
    "defaultAxisMajorStroke": [{ type: Input },],
    "defaultAxisMinorStroke": [{ type: Input },],
    "plotAreaMarginLeft": [{ type: Input },],
    "plotAreaMarginTop": [{ type: Input },],
    "plotAreaMarginRight": [{ type: Input },],
    "plotAreaMarginBottom": [{ type: Input },],
};
//# sourceMappingURL=igx-data-chart-component.js.map