/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Component, EventEmitter, Output, ViewChild, ChangeDetectionStrategy, TemplateRef, ChangeDetectorRef } from '@angular/core';
import { TypeRegistrar } from './type';
export class IgxDataChartDefaultTooltipsComponent {
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        this.onContentReady = new EventEmitter();
    }
    ensureDefaultTooltip(series) {
        if (series.isCategory &&
            !series.isVertical &&
            !series.isFinancial &&
            !series.isRange) {
            if (series.showDefaultTooltip) {
                series.tooltipTemplate = this.anchoredCategoryTooltip;
            }
            else {
                if (series.tooltipTemplate === this.anchoredCategoryTooltip) {
                    series.tooltipTemplate = null;
                }
            }
        }
        if (series.isFinancial) {
            if (series.showDefaultTooltip) {
                series.tooltipTemplate = this.financialTooltip;
            }
            else {
                if (series.tooltipTemplate === this.financialTooltip) {
                    series.tooltipTemplate = null;
                }
            }
        }
    }
    format(value) {
        if (value.getTime) {
            return this.shortDate(value);
        }
        return value.toString();
    }
    shortDate(item) {
        return item.toLocaleDateString() + " " + item.toLocaleTimeString();
    }
    hasOpen(series) {
        return series.openMemberPath;
    }
    getOpenValue(series, item) {
        return item[series.openMemberPath];
    }
    hasHigh(series) {
        return series.highMemberPath;
    }
    getHighValue(series, item) {
        return item[series.highMemberPath];
    }
    hasLow(series) {
        return series.lowMemberPath;
    }
    getLowValue(series, item) {
        return item[series.lowMemberPath];
    }
    hasClose(series) {
        return series.closeMemberPath;
    }
    getCloseValue(series, item) {
        return item[series.closeMemberPath];
    }
    hasVolume(series) {
        return series.volumeMemberPath;
    }
    getVolumeValue(series, item) {
        return item[series.volumeMemberPath];
    }
    getAnchoredValue(series, item) {
        return item[series.valueMemberPath];
    }
    getBrush(series) {
        return series.actualBrush;
    }
    asAny(item) {
        return item;
    }
    static register() {
        TypeRegistrar.registerCons("IgxDataChartDefaultTooltipsComponent", IgxDataChartDefaultTooltipsComponent);
    }
    ngAfterContentInit() {
        this.onContentReady.emit({});
    }
}
IgxDataChartDefaultTooltipsComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-data-chart-default-tooltips',
                changeDetection: ChangeDetectionStrategy.OnPush,
                template: `
    <ng-template #anchoredCategoryTooltip let-series="series" let-item="item">
        <div class='ui-chart-default-tooltip-content' *ngIf="item">            
            <span *ngIf="series.xAxis.isDateTime">{{shortDate(asAny(item)[asAny(series.xAxis).dateTimeMemberPath])}}</span>
            <br *ngIf="series.xAxis.isDateTime" />
            <span *ngIf="!series.xAxis.isDateTime && series.xAxis.label">{{format(asAny(item)[series.xAxis.label])}}</span>
            <br *ngIf="!series.xAxis.isDateTime && series.xAxis.label" />
            <span [style.color]="getBrush(series)">{{series.title}}: </span>
            <span class="ui-tooltip-priority">{{getAnchoredValue(series, item)}}</span>
        </div>
    </ng-template>
    <ng-template #financialTooltip let-series="series" let-item="item">
        <div class='ui-chart-default-tooltip-content' *ngIf="item">            
            <span *ngIf="series.xAxis.isDateTime">{{shortDate(asAny(item)[asAny(series.xAxis).dateTimeMemberPath])}}</span>
            <br *ngIf="series.xAxis.isDateTime" />
            <span *ngIf="!series.xAxis.isDateTime && series.xAxis.label">{{format(asAny(item)[series.xAxis.label])}}</span>
            <br *ngIf="!series.xAxis.isDateTime && series.xAxis.label" />
            <span [style.color]="getBrush(series)">{{series.title}}: </span>
            <table>
                <tr *ngIf="hasOpen(series)"><td>Open:</td><td>{{getOpenValue(series, item)}}</td></tr>
                <tr *ngIf="hasHigh(series)"><td>High:</td><td>{{getHighValue(series, item)}}</td></tr>
                <tr *ngIf="hasLow(series)"><td>Low:</td><td>{{getLowValue(series, item)}}</td></tr>
                <tr *ngIf="hasClose(series)"><td>Close:</td><td>{{getCloseValue(series, item)}}</td></tr>
                <tr *ngIf="hasVolume(series)"><td>Volume:</td><td>{{getVolumeValue(series, item)}}</td></tr>
            </table>
        </div>
    </ng-template>
  `,
                styles: []
            },] },
];
/** @nocollapse */
IgxDataChartDefaultTooltipsComponent.ctorParameters = () => [
    { type: ChangeDetectorRef, },
];
IgxDataChartDefaultTooltipsComponent.propDecorators = {
    "anchoredCategoryTooltip": [{ type: ViewChild, args: ["anchoredCategoryTooltip",] },],
    "financialTooltip": [{ type: ViewChild, args: ["financialTooltip",] },],
    "onContentReady": [{ type: Output },],
};
//# sourceMappingURL=igx-data-chart-default-tooltips-component.js.map