/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { forwardRef, Input } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxNumericYAxisComponent } from './igx-numeric-y-axis-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxCategorySeriesComponent } from './igx-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { toPoint, fromPoint, fromRect } from './componentUtil';
export const IgxHorizontalAnchoredCategorySeriesComponent_PROVIDERS = [{ provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxHorizontalAnchoredCategorySeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxHorizontalAnchoredCategorySeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxHorizontalAnchoredCategorySeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxHorizontalAnchoredCategorySeriesComponent) }];
/**
 * Base class for anchored category series with a category x-axis and a numeric y-axis.
*
* Instantiate HorizontalAnchoredCategorySeries
*/
export class IgxHorizontalAnchoredCategorySeriesComponent extends IgxAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the effective x-axis for this series.
        *
        * Instantiate xAxis
        */
    get xAxis() {
        if (this.i.xAxis == null) {
            return null;
        }
        return this.i.xAxis.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.xAxis = null : this.i.xAxis = v.i;
    }
    /**
         * Gets or sets the effective y-axis for this series.
        *
        * Instantiate yAxis
        */
    get yAxis() {
        if (this.i.yAxis == null) {
            return null;
        }
        if (!this.i.yAxis.externalObject) {
            let e = new IgxNumericYAxisComponent();
            e._implementation = this.i.yAxis;
            this.i.yAxis.externalObject = e;
        }
        return this.i.yAxis.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.yAxis = null : this.i.yAxis = v.i;
    }
    /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        *
        * You can use the `getCategoryWidth` to get the width of the category grouping a series is in.
        *
        * <!-- Angular JS -->
        *
        *     var x = financialSeries.GetSeriesValueMarkerBoundingBox(new IgxPoint());
        *
        * <!-- Ignite JS -->
        *
        *      N/A
        */
    getSeriesValueMarkerBoundingBox(world) {
        let iv = this.i.lb(toPoint(world));
        return fromRect(iv);
    }
    /**
         * Returns the offset value for this series if grouped on a category axis.
        
        *
        * You can use the `getOffsetValue` to get the offset value for this series if grouped on a category axis.
        *
        * <!-- Angular JS -->
        *
        *       var g = series.getOffsetValue();
        *
        * <!-- Ignite JS -->
        *
        *      N/A
        */
    getOffsetValue() {
        let iv = this.i.getOffsetValue();
        return (iv);
    }
    /**
         * Returns the width of the category grouping this series is in.
        
        *
        * You can use the `getCategoryWidth` to get the width of the category grouping a series is in.
        *
        * <!-- Angular JS -->
        *
        *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
        *
        * <!-- Ignite JS -->
        *
        *      N/A
        */
    getCategoryWidth() {
        let iv = this.i.getCategoryWidth();
        return (iv);
    }
    getSeriesValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ed(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getPreviousOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e3(toPoint(world), skipUnknowns);
        return (iv);
    }
    getNextOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e1(toPoint(world), skipUnknowns);
        return (iv);
    }
    getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.k0(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        *
        * You can use the `canUseAsXAxis` method to determine if object can be used as XAxis
        *
        * <!-- Angular JS -->
        *
        *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
        *
        * <!-- Ignite JS -->
        *
        *      N/A
        */
    canUseAsXAxis(axis) {
        let iv = this.i.pl(axis);
        return (iv);
    }
    /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        *
        * You can use the `canUseAsYAxis` method to determine if object can be used as YAxis
        *
        * <!-- Ignite JS -->
        *
        *      N/A
        */
    canUseAsYAxis(axis) {
        let iv = this.i.pm(axis);
        return (iv);
    }
}
IgxHorizontalAnchoredCategorySeriesComponent.propDecorators = {
    "xAxis": [{ type: Input },],
    "yAxis": [{ type: Input },],
};
//# sourceMappingURL=igx-horizontal-anchored-category-series-component.js.map