import { Component, Renderer2, ElementRef, Inject, forwardRef, Input, NgZone, ChangeDetectionStrategy } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { IgxLegendBaseComponent } from './igx-legend-base-component';
import { Legend } from "./Legend";
import { LegendOrientation, LegendOrientation_$type } from './LegendOrientation';
import { AngularRenderer } from './angular-renderer';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { ensureEnum } from './componentUtil';
export const IgxLegendComponent_PROVIDERS = [{ provide: IgxLegendBaseComponent, useExisting: forwardRef(() => IgxLegendComponent) }];
/**
 * Represents a legend in a IgxDataChartComponent control.
*
* The `IgxLegendComponent` helps end-user identify visuals of chart series with contextual information related to the data plotted in the chart control.
*
* ```html
* angular
* ```
*/
export class IgxLegendComponent extends IgxLegendBaseComponent {
    constructor(renderer, elRef, document, ngZone) {
        super();
        this.renderer = renderer;
        this.elRef = elRef;
        this.document = document;
        this.ngZone = ngZone;
        this._zoneRunner = (act) => this.ngZone.run(act);
        this.container = renderer.createElement("div");
        renderer.appendChild(elRef.nativeElement, this.container);
        var root;
        root = this.container;
        if (this.container != null) {
            root = this.container;
        }
        var ren = new AngularRenderer(root, this.renderer, this.document, this.ngZone, true, DataChartStylingDefaults);
        this._wrapper = ren;
        this.i.provideContainer(ren);
    }
    ngOnDestroy() {
        this._wrapper.destroy();
    }
    createImplementation() {
        return new Legend();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the current Legend object's orientation.
        */
    get orientation() {
        return this.i.a9;
    }
    set orientation(v) {
        this.i.a9 = ensureEnum(LegendOrientation_$type, v);
    }
    /**
         * Gets or sets color of text
        */
    get textColor() {
        return this.i.bf;
    }
    set textColor(v) {
        this.i.bf = v;
    }
    /**
         * Gets or sets style of text.
        */
    get textStyle() {
        return this.i.bg;
    }
    set textStyle(v) {
        this.i.bg = v;
    }
}
IgxLegendComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-legend',
                template: ``,
                providers: [{ provide: IgxLegendBaseComponent, useExisting: forwardRef(() => IgxLegendComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [`
		:host {
			display: block;
		}
	`]
            },] },
];
/** @nocollapse */
IgxLegendComponent.ctorParameters = () => [
    { type: Renderer2, },
    { type: ElementRef, },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgZone, },
];
IgxLegendComponent.propDecorators = {
    "orientation": [{ type: Input },],
    "textColor": [{ type: Input },],
    "textStyle": [{ type: Input },],
};
//# sourceMappingURL=igx-legend-component.js.map