/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { EventEmitter, Output, TemplateRef, Input } from '@angular/core';
import { Visibility, Visibility_$type } from './Visibility';
import { TransitionInSpeedType, TransitionInSpeedType_$type } from './TransitionInSpeedType';
import { SeriesHitTestMode, SeriesHitTestMode_$type } from './SeriesHitTestMode';
import { brushToString, stringToBrush, toPoint, fromPoint, fromRect, stringToColor, colorToString, ensureEnum, ensureBool } from './componentUtil';
import { RenderRequestedEventArgs } from './RenderRequestedEventArgs';
import { delegateCombine, TypeRegistrar } from './type';
export const IgxSeriesComponent_PROVIDERS = [];
/**
 * Represents the base class for all IgxDataChartComponent series.
*/
export class IgxSeriesComponent {
    constructor() {
        this._chartLevelData = null;
        this._dataSource = null;
        this._tooltipTemplate = null;
        this._tooltipContent = null;
        this._tooltipContainerTemplate = null;
        this._renderer = null;
        this._renderRequested = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    createImplementation() {
        return null;
    }
    get seriesInternal() {
        return this.i;
    }
    ngOnInit() {
    }
    set name(value) {
        this.i.name = value;
    }
    get name() {
        return this.i.name;
    }
    provideData(data) {
        this._chartLevelData = data;
        this.updateDataSource();
    }
    updateDataSource() {
        if (this._dataSource == null) {
            this.i.itemsSource = this._chartLevelData;
        }
        else {
            this.i.itemsSource = this._dataSource;
        }
    }
    set dataSource(value) {
        this._dataSource = value;
        this.updateDataSource();
        //console.log("setting axis data source: " + value)
    }
    get dataSource() {
        if (this._dataSource != null) {
            return this._dataSource;
        }
        return this.i.itemsSource;
    }
    bindAxes(axes) {
    }
    set tooltipTemplate(value) {
        this._tooltipTemplate = value;
        if (value == null) {
            if (this._tooltipContent !== null) {
                this._tooltipContent.destroy();
                this._tooltipContent = null;
            }
        }
        if (this._tooltipContent != null) {
            this._tooltipContent.instance.template = this._tooltipTemplate;
        }
        else {
            if (this.owner != null) {
                this.owner._ensureTooltipCreated(this);
            }
        }
    }
    get tooltipTemplate() {
        return this._tooltipTemplate;
    }
    set tooltipContainerTemplate(value) {
        this._tooltipContainerTemplate = value;
        if (this._tooltipContent != null) {
            this._tooltipContent.instance.containerTemplate = this._tooltipContainerTemplate;
        }
    }
    get tooltipContainerTemplate() {
        return this._tooltipContainerTemplate;
    }
    _ensureTooltipCreated(createTooltip, createWrapper) {
        if (this._tooltipTemplate == null) {
            this.i.toolTip = null;
        }
        if (this._tooltipContent == null && this._tooltipTemplate != null) {
            let tooltip = createTooltip();
            if (tooltip == null) {
                return;
            }
            this._tooltipContent = tooltip;
            tooltip.instance.template = this._tooltipTemplate;
            this.i.toolTip = createWrapper(tooltip.location.nativeElement);
        }
    }
    _ensureTooltipDestroyed() {
        if (this._tooltipContent !== null) {
            this._tooltipContent.destroy();
            this._tooltipContent = null;
        }
    }
    _provideRenderer(renderer) {
        this._renderer = renderer;
        this._zoneRunner = (act) => renderer._ngZone.run(act);
    }
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    /**
         * Gets whether the series is an annotation layer.
        */
    get isAnnotationLayer() {
        return this.i.ch;
    }
    /**
         * Gets whether the current series is oriented vertically.
        */
    get isVertical() {
        return this.i.isVertical;
    }
    /**
         * Gets whether the current series is a stack fragment.
        */
    get isFragment() {
        return this.i.cq;
    }
    /**
         * Gets whether the current series shows an area or line shape.
        */
    get isAreaOrLine() {
        return this.i.ci;
    }
    /**
         * Gets whether the current series is a polar type series.
        */
    get isPolar() {
        return this.i.cy;
    }
    /**
         * Gets whether the current series is a scatter type series.
        */
    get isScatter() {
        return this.i.c2;
    }
    /**
         * Gets whether the current series is a radial type series.
        */
    get isRadial() {
        return this.i.c0;
    }
    /**
         * Gets whether the current series is a stacked type series.
        */
    get isStacked() {
        return this.i.isStacked;
    }
    /**
         * Gets whether the current series is a financial type series.
        */
    get isFinancial() {
        return this.i.cp;
    }
    /**
         * Gets whether the current series is a range type series.
        */
    get isRange() {
        return this.i.c1;
    }
    /**
         * Gets whether the current series is a category type series.
        */
    get isCategory() {
        return this.i.cj;
    }
    /**
         * Gets whether the current seires is a geogrpahic series.
        */
    get isGeographic() {
        return this.i.cr;
    }
    /**
         * Gets whether the default crosshair behavior should be disabled if this series is present.
        */
    get isDefaultCrosshairBehaviorDisabled() {
        return this.i.ck;
    }
    /**
         * Gets whether the default tooltip behavior should be disabled if this series is present.
        */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.cl;
    }
    /**
         * Returns whether the current series supports visual markers.
        */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
    get isIndexed() {
        return this.i.cu;
    }
    /**
         * Gets if the series should appear in any legends.
        */
    get isUsableInLegend() {
        return this.i.isUsableInLegend;
    }
    /**
         * Gets or sets the legend item visibility for the current series object.
        */
    get legendItemVisibility() {
        return this.i.le;
    }
    set legendItemVisibility(v) {
        this.i.le = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets the LegendItemBadgeTemplate property.
         * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
         * the series object itself.
        */
    get legendItemBadgeTemplate() {
        return this.i.legendItemBadgeTemplate;
    }
    set legendItemBadgeTemplate(v) {
        this.i.legendItemBadgeTemplate = v;
    }
    /**
         * Gets or sets the LegendItemTemplate property.
         * The legend item control content is created according to the LegendItemTemplate on-demand by
         * the series object itself.
        */
    get legendItemTemplate() {
        return this.i.legendItemTemplate;
    }
    set legendItemTemplate(v) {
        this.i.legendItemTemplate = v;
    }
    /**
         * Gets or sets the DiscreteLegendItemTemplate property.
         * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by
         * the series object itself.
        */
    get discreteLegendItemTemplate() {
        return this.i.jd;
    }
    set discreteLegendItemTemplate(v) {
        this.i.jd = v;
    }
    /**
         * Gets or sets the easing function used to morph the current series.
        */
    get transitionEasingFunction() {
        return this.i.bt;
    }
    set transitionEasingFunction(v) {
        this.i.bt = v;
    }
    /**
         * Gets or sets the EasingFunction used to morph the current series during the initial transition.
        */
    get transitionInEasingFunction() {
        return this.i.bu;
    }
    set transitionInEasingFunction(v) {
        this.i.bu = v;
    }
    /**
         * Gets or sets the duration of the current series's morph.
        */
    get transitionDuration() {
        return this.i.e7;
    }
    set transitionDuration(v) {
        this.i.e7 = +v;
    }
    /**
         * Gets or sets the current series object's rendering resolution.
        */
    get resolution() {
        return this.i.ej;
    }
    set resolution(v) {
        this.i.ej = +v;
    }
    /**
         * Gets or sets the Title property.
         * The legend item control is created according to the Title on-demand by
         * the series object itself.
        */
    get title() {
        return this.i.fj;
    }
    set title(v) {
        this.i.fj = v;
    }
    /**
         * Gets or sets the brush to use for the series.
        *
        * Sets the effective brush for the series.
        *
        * ```html
        * <igx-data-chart #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-area-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         brush="red">
        *     </igx-area-series>
        * </igx-data-chart>
        * ```
        */
    get brush() {
        return brushToString(this.i.kk);
    }
    set brush(v) {
        this.i.kk = stringToBrush(v);
    }
    /**
         * Gets the effective brush for the current series object.
        *
        * Gets the effective brush for the series.
        */
    get actualBrush() {
        return brushToString(this.i.ki);
    }
    /**
         * Gets or sets the brush to use for the outline of the series.
         * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
        */
    get outline() {
        return brushToString(this.i.kn);
    }
    set outline(v) {
        this.i.kn = stringToBrush(v);
    }
    /**
         * Gets the effective outline for the current series object.
        *
        * Get the effective outline for the series.
        */
    get actualOutline() {
        return brushToString(this.i.kj);
    }
    /**
         * Gets or sets the width of the current series object's line thickness.
        */
    get thickness() {
        return this.i.en;
    }
    set thickness(v) {
        this.i.en = +v;
    }
    /**
         * Gets or sets whether highlighting should be enabled for this series, if this type of series supports highlighting.
        */
    get isHighlightingEnabled() {
        return this.i.cs;
    }
    set isHighlightingEnabled(v) {
        this.i.cs = ensureBool(v);
    }
    /**
         * Gets or sets whether drop shadow should be enabled for this series.
        */
    get isDropShadowEnabled() {
        return this.i.cn;
    }
    set isDropShadowEnabled(v) {
        this.i.cn = ensureBool(v);
    }
    /**
         * Gets or sets the shadow blur.
         * This property is ignored when Series.UseSingleShadow is set to true.
        */
    get shadowBlur() {
        return this.i.ek;
    }
    set shadowBlur(v) {
        this.i.ek = +v;
    }
    /**
         * Gets or sets the drop shadow color.
        */
    get shadowColor() {
        return colorToString(this.i.kp);
    }
    set shadowColor(v) {
        this.i.kp = stringToColor(v);
    }
    /**
         * Gets or sets whether drop shadow is applied to the whole series visual or to each of the individual shapes forming the series.
         * When this property is set to true, no Series.ShadowBlur is applied.
        */
    get useSingleShadow() {
        return this.i.dq;
    }
    set useSingleShadow(v) {
        this.i.dq = ensureBool(v);
    }
    /**
         * Gets or sets the drop shadow x-offset.
        */
    get shadowOffsetX() {
        return this.i.el;
    }
    set shadowOffsetX(v) {
        this.i.el = +v;
    }
    /**
         * Gets or sets the drop shadow y-offset.
        */
    get shadowOffsetY() {
        return this.i.em;
    }
    set shadowOffsetY(v) {
        this.i.em = +v;
    }
    /**
         * Gets or sets the opacity applied to the area fill visual.
         * This property only applies to series that have area visual.
        *
        * Sets the opacity applied to the area fill visual.
        *
        * ```html
        * <igx-data-chart #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-area-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         areaFillOpacity=.5>
        *     </igx-area-series>
        * </igx-data-chart>
        * ```
        */
    get areaFillOpacity() {
        return this.i.dz;
    }
    set areaFillOpacity(v) {
        this.i.dz = +v;
    }
    /**
         * Gets the actual opacity applied to the area fill visual.
        *
        * Gets the effective opacity applied to the area fill visual.
        */
    get actualAreaFillOpacity() {
        return this.i.dy;
    }
    /**
         * Gets if the default tooltip has been selected for display.
        */
    get isDefaultToolTipSelected() {
        return this.i.cm;
    }
    set isDefaultToolTipSelected(v) {
        this.i.cm = ensureBool(v);
    }
    /**
         * Gets or sets whether default tooltip will be shown.
        */
    get showDefaultTooltip() {
        return this.i.c9;
    }
    set showDefaultTooltip(v) {
        this.i.c9 = ensureBool(v);
    }
    /**
         * Gets or sets the duration of the current series's transition in morph.
        */
    get transitionInDuration() {
        return this.i.e8;
    }
    set transitionInDuration(v) {
        this.i.e8 = +v;
    }
    /**
         * Gets or sets the duration of the current series's transition in morph.
        */
    get transitionInSpeedType() {
        return this.i.bo;
    }
    set transitionInSpeedType(v) {
        this.i.bo = ensureEnum(TransitionInSpeedType_$type, v);
    }
    /**
         * Gets or sets the whether the chart reacts to mouse move events.
        */
    get mouseOverEnabled() {
        return this.i.c3;
    }
    set mouseOverEnabled(v) {
        this.i.c3 = ensureBool(v);
    }
    /**
         * Gets or gets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
    get coercionMethods() {
        return this.i.coercionMethods;
    }
    set coercionMethods(v) {
        this.i.coercionMethods = v;
    }
    /**
         * Gets or sets whether the series should expect that properties in its items source may be functions that need to be
         * evaluated to yield their value. This defaults to false, as there will be a subtle performance impact to using this feature.
         * This value must be set before assigning an item's source to take effect.
        */
    get expectFunctions() {
        return this.i.expectFunctions;
    }
    set expectFunctions(v) {
        this.i.expectFunctions = ensureBool(v);
    }
    /**
         * Method of hit testing to use when pointing to items in this series.
        */
    get hitTestMode() {
        return this.i.bd;
    }
    set hitTestMode(v) {
        this.i.bd = ensureEnum(SeriesHitTestMode_$type, v);
    }
    /**
         * Resolved method of hit testing to use when pointing to items in the chart.
        */
    get actualHitTestMode() {
        return this.i.bb;
    }
    get isNegativeColorSupported() {
        return this.i.cx;
    }
    get isMarkerlessDisplayPreferred() {
        return this.i.cw;
    }
    resolveTooltipBrush() {
        let iv = this.i.ge();
        return (iv);
    }
    /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        *
        * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, `getExactItemIndex` will return the same integer value as `getItemIndex`.
        */
    getExactItemIndex(world) {
        let iv = this.i.d2(toPoint(world));
        return (iv);
    }
    /**
         * Gets the item item index associated with the specified world position
        
        *
        * Gets the item item index associated with the specified world position.
        */
    getItemIndex(world) {
        let iv = this.i.ex(toPoint(world));
        return (iv);
    }
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        *
        * Gets the item that is the best match for the specified world coordinates.
        */
    getItem(world) {
        let iv = this.i.fe(toPoint(world));
        return (iv);
    }
    getPreviousOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e3(toPoint(world), skipUnknowns);
        return (iv);
    }
    getNextOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e1(toPoint(world), skipUnknowns);
        return (iv);
    }
    getSeriesValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ed(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.k0(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        *
        * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        */
    getSeriesValueBoundingBox(world) {
        let iv = this.i.k9(toPoint(world));
        return fromRect(iv);
    }
    /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
    getSeriesValueMarkerBoundingBox(world) {
        let iv = this.i.lb(toPoint(world));
        return fromRect(iv);
    }
    getSeriesHighValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.d9(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesHighValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.kw(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesLowValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.eb(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getSeriesLowValuePosition(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ky(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesValuePositionFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
        let iv = this.i.k1(toPoint(mouse), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    }
    getSeriesValueFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
        let iv = this.i.ee(toPoint(mouse), useInterpolation, skipUnknowns);
        return (iv);
    }
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        *
        * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        */
    getItemSpan() {
        let iv = this.i.d7();
        return (iv);
    }
    /**
         * Converts a point from coordinates within the series plot area to a world position within axis space.
        
        * @param seriesPoint  * The pixel location within the plot area of the series.
        */
    toWorldPosition(seriesPoint) {
        let iv = this.i.k3(toPoint(seriesPoint));
        return fromPoint(iv);
    }
    /**
         * Converts a point from world coordinates to coordinates within the viewport of the series.
        
        * @param world  * The world position from which to convert.
        *
        * Converts a point from world coordinates to coordinates within the viewport of the series.
        */
    fromWorldPosition(world) {
        let iv = this.i.kv(toPoint(world));
        return fromPoint(iv);
    }
    /**
         * Requests that the provided item should be brought into view if possible.
        
        * @param item  * The item to attempt to bring into view.
        */
    scrollIntoView(item) {
        let iv = this.i.c5(item);
        return (iv);
    }
    /**
         * Renders the series.
        
        * @param animate  * True if the change should be animated.
        */
    renderSeries(animate) {
        this.i.it(animate);
    }
    /**
         * Gets the effective viewport, adjusted to account for margins and other factors.
        
        */
    getEffectiveViewport() {
        let iv = this.i.getEffectiveViewport();
        return fromRect(iv);
    }
    removeAllAlternateViews() {
        this.i.io();
    }
    removeAlternateView(viewIdentifier) {
        this.i.iq(viewIdentifier);
    }
    /**
         * Replays the assigned transition in animation, if any.
        
        */
    replayTransitionIn() {
        this.i.iw();
    }
    /**
         * Simulates a pointer hover over the series surface.
        
        * @param point  * The pointer position relative to the series viewport over which to hover.
        */
    simulateHover(point) {
        this.i.i0(toPoint(point));
    }
    styleUpdated() {
        this.i.i2();
    }
    setNegativeColors(negativeBrush, negativeOutline) {
        this.i.iy(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    }
    /**
         * Moves the cursor point to the provided world position. Some series may react to the current cursor position.
        
        * @param point  * The cursor point, in world coordinates.
        */
    moveCursorPoint(point) {
        this.i.hu(toPoint(point));
    }
    /**
         * This event is raised every time a render has been requested from a series.
        */
    get renderRequested() {
        if (this._renderRequested == null) {
            this._renderRequested = new EventEmitter();
            this.i.renderRequested = delegateCombine(this.i.renderRequested, (o, e) => {
                let outerArgs = new RenderRequestedEventArgs();
                outerArgs._provideImplementation(e);
                this._renderRequested.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._renderRequested;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxSeriesComponent.propDecorators = {
    "name": [{ type: Input },],
    "dataSource": [{ type: Input },],
    "tooltipTemplate": [{ type: Input },],
    "tooltipContainerTemplate": [{ type: Input },],
    "legendItemVisibility": [{ type: Input },],
    "legendItemBadgeTemplate": [{ type: Input },],
    "legendItemTemplate": [{ type: Input },],
    "discreteLegendItemTemplate": [{ type: Input },],
    "transitionEasingFunction": [{ type: Input },],
    "transitionInEasingFunction": [{ type: Input },],
    "transitionDuration": [{ type: Input },],
    "resolution": [{ type: Input },],
    "title": [{ type: Input },],
    "brush": [{ type: Input },],
    "outline": [{ type: Input },],
    "thickness": [{ type: Input },],
    "isHighlightingEnabled": [{ type: Input },],
    "isDropShadowEnabled": [{ type: Input },],
    "shadowBlur": [{ type: Input },],
    "shadowColor": [{ type: Input },],
    "useSingleShadow": [{ type: Input },],
    "shadowOffsetX": [{ type: Input },],
    "shadowOffsetY": [{ type: Input },],
    "areaFillOpacity": [{ type: Input },],
    "isDefaultToolTipSelected": [{ type: Input },],
    "showDefaultTooltip": [{ type: Input },],
    "transitionInDuration": [{ type: Input },],
    "transitionInSpeedType": [{ type: Input },],
    "mouseOverEnabled": [{ type: Input },],
    "coercionMethods": [{ type: Input },],
    "expectFunctions": [{ type: Input },],
    "hitTestMode": [{ type: Input },],
    "renderRequested": [{ type: Output },],
};
//# sourceMappingURL=igx-series-component.js.map