import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxHorizontalAnchoredCategorySeriesComponent } from './igx-horizontal-anchored-category-series-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxCategorySeriesComponent } from './igx-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { WaterfallSeries } from "./WaterfallSeries";
import { brushToString, stringToBrush, toPoint, fromRect } from "./componentUtil";
/**
 * Represents a IgxDataChartComponent waterfall column series.
*/
export const IgxWaterfallSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }];
export class IgxWaterfallSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new WaterfallSeries();
    }
    get i() {
        return this._implementation;
    }
    get isNegativeColorSupported() {
        return this.i.cx;
    }
    /**
         * Gets or sets the brush to use for negative portions of the series.
        */
    get negativeBrush() {
        return brushToString(this.i.p7);
    }
    set negativeBrush(v) {
        this.i.p7 = stringToBrush(v);
    }
    /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusX() {
        return this.i.px;
    }
    set radiusX(v) {
        this.i.px = +v;
    }
    /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusY() {
        return this.i.py;
    }
    set radiusY(v) {
        this.i.py = +v;
    }
    /**
         * Brush to use for outlining negative elements in the waterfall series.
        */
    get negativeOutline() {
        return brushToString(this.i.p8);
    }
    set negativeOutline(v) {
        this.i.p8 = stringToBrush(v);
    }
    setNegativeColors(negativeBrush, negativeOutline) {
        this.i.iy(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    }
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    getSeriesValueBoundingBox(world) {
        let iv = this.i.k9(toPoint(world));
        return fromRect(iv);
    }
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    getItemSpan() {
        let iv = this.i.d7();
        return (iv);
    }
}
IgxWaterfallSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-waterfall-series',
                template: ``,
                providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxWaterfallSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxWaterfallSeriesComponent.ctorParameters = () => [];
IgxWaterfallSeriesComponent.propDecorators = {
    "negativeBrush": [{ type: Input },],
    "radiusX": [{ type: Input },],
    "radiusY": [{ type: Input },],
    "negativeOutline": [{ type: Input },],
};
//# sourceMappingURL=igx-waterfall-series-component.js.map