import { Output, EventEmitter, Component, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, ViewChild, Inject, Input, NgZone, ChangeDetectionStrategy } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { ZoomSliderOrientation, ZoomSliderOrientation_$type } from './ZoomSliderOrientation';
import { ZoomSliderResolvingAxisValueEventArgs } from './igx-zoom-slider-resolving-axis-value-event-args';
import { RectChangedEventArgs } from './igx-rect-changed-event-args';
import { ZoomSlider } from "./ZoomSlider";
import { fromRect, toRect, ensureEnum, brushToString, stringToBrush, ensureBool } from "./componentUtil";
import { FontInfo } from "./FontInfo";
import { AngularRenderer } from './angular-renderer';
import { delegateCombine } from './type';
export const IgxZoomSliderComponent_PROVIDERS = [];
const ZoomSliderStylingDefaults = {};
export class IgxZoomSliderComponent {
    constructor(renderer, _elRef, document, ngZone, injector, componentFactoryResolver) {
        this.renderer = renderer;
        this._elRef = _elRef;
        this.document = document;
        this.ngZone = ngZone;
        this.injector = injector;
        this.componentFactoryResolver = componentFactoryResolver;
        this._wrapper = null;
        this._implementation = null;
        this._resolvingAxisValue = null;
        this._windowRectChanged = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this.container = renderer.createElement("div");
        renderer.appendChild(_elRef.element.nativeElement, this.container);
        renderer.setStyle(this.container, "display", "block");
        renderer.setStyle(this.container, "width", "100%");
        renderer.setStyle(this.container, "height", "100%");
        var root;
        root = this.container;
        if (this.container != null) {
            root = this.container;
        }
        var ren = new AngularRenderer(root, this.renderer, this.document, this.ngZone, true, ZoomSliderStylingDefaults);
        this._wrapper = ren;
        var zoomSlider = this.i;
        this._zoomSlider = zoomSlider;
        zoomSlider.provideContainer(ren);
        zoomSlider.notifySizeChanged();
        ren.addSizeWatcher(() => {
            this._zoomSlider.notifySizeChanged();
        });
    }
    set height(value) {
        this._height = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "height", value);
        this._zoomSlider.notifySizeChanged();
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "width", value);
        this._zoomSlider.notifySizeChanged();
    }
    get width() {
        return this._width;
    }
    ngOnDestroy() {
        this._zoomSlider.destroy();
        this._wrapper.destroy();
    }
    ngAfterContentInit() {
    }
    createImplementation() {
        return new ZoomSlider();
    }
    get i() {
        return this._implementation;
    }
    get panTransitionDuration() {
        return this.i.br;
    }
    set panTransitionDuration(v) {
        this.i.br = +v;
    }
    get maxZoomWidth() {
        return this.i.bj;
    }
    set maxZoomWidth(v) {
        this.i.bj = +v;
    }
    get pixelScalingRatio() {
        return this.i.bl;
    }
    set pixelScalingRatio(v) {
        this.i.bl = +v;
    }
    get actualPixelScalingRatio() {
        return this.i.a5;
    }
    set actualPixelScalingRatio(v) {
        this.i.a5 = +v;
    }
    get windowRect() {
        return fromRect(this.i.fs);
    }
    set windowRect(v) {
        this.i.fs = toRect(v);
    }
    get minZoomWidth() {
        return this.i.bk;
    }
    set minZoomWidth(v) {
        this.i.bk = +v;
    }
    get startInset() {
        return this.i.bn;
    }
    set startInset(v) {
        this.i.bn = +v;
    }
    get endInset() {
        return this.i.a8;
    }
    set endInset(v) {
        this.i.a8 = +v;
    }
    get trackStartInset() {
        return this.i.bp;
    }
    set trackStartInset(v) {
        this.i.bp = +v;
    }
    get trackEndInset() {
        return this.i.bo;
    }
    set trackEndInset(v) {
        this.i.bo = +v;
    }
    get barExtent() {
        return this.i.a6;
    }
    set barExtent(v) {
        this.i.a6 = +v;
    }
    get orientation() {
        return this.i.e;
    }
    set orientation(v) {
        this.i.e = ensureEnum(ZoomSliderOrientation_$type, v);
    }
    get lowerThumbBrush() {
        return brushToString(this.i.fg);
    }
    set lowerThumbBrush(v) {
        this.i.fg = stringToBrush(v);
    }
    get lowerThumbStrokeThickness() {
        return this.i.bh;
    }
    set lowerThumbStrokeThickness(v) {
        this.i.bh = +v;
    }
    get higherThumbStrokeThickness() {
        return this.i.bc;
    }
    set higherThumbStrokeThickness(v) {
        this.i.bc = +v;
    }
    get higherThumbBrush() {
        return brushToString(this.i.e8);
    }
    set higherThumbBrush(v) {
        this.i.e8 = stringToBrush(v);
    }
    get lowerThumbOutline() {
        return brushToString(this.i.fh);
    }
    set lowerThumbOutline(v) {
        this.i.fh = stringToBrush(v);
    }
    get higherThumbOutline() {
        return brushToString(this.i.e9);
    }
    set higherThumbOutline(v) {
        this.i.e9 = stringToBrush(v);
    }
    get lowerThumbRidgesBrush() {
        return brushToString(this.i.fi);
    }
    set lowerThumbRidgesBrush(v) {
        this.i.fi = stringToBrush(v);
    }
    get higherThumbRidgesBrush() {
        return brushToString(this.i.fa);
    }
    set higherThumbRidgesBrush(v) {
        this.i.fa = stringToBrush(v);
    }
    get lowerThumbWidth() {
        return this.i.bi;
    }
    set lowerThumbWidth(v) {
        this.i.bi = +v;
    }
    get higherThumbWidth() {
        return this.i.bd;
    }
    set higherThumbWidth(v) {
        this.i.bd = +v;
    }
    get lowerThumbHeight() {
        return this.i.bg;
    }
    set lowerThumbHeight(v) {
        this.i.bg = +v;
    }
    get higherThumbHeight() {
        return this.i.bb;
    }
    set higherThumbHeight(v) {
        this.i.bb = +v;
    }
    get lowerShadeBrush() {
        return brushToString(this.i.fe);
    }
    set lowerShadeBrush(v) {
        this.i.fe = stringToBrush(v);
    }
    get lowerShadeOutline() {
        return brushToString(this.i.ff);
    }
    set lowerShadeOutline(v) {
        this.i.ff = stringToBrush(v);
    }
    get lowerShadeStrokeThickness() {
        return this.i.bf;
    }
    set lowerShadeStrokeThickness(v) {
        this.i.bf = +v;
    }
    get higherShadeBrush() {
        return brushToString(this.i.e6);
    }
    set higherShadeBrush(v) {
        this.i.e6 = stringToBrush(v);
    }
    get higherShadeOutline() {
        return brushToString(this.i.e7);
    }
    set higherShadeOutline(v) {
        this.i.e7 = stringToBrush(v);
    }
    get higherShadeStrokeThickness() {
        return this.i.ba;
    }
    set higherShadeStrokeThickness(v) {
        this.i.ba = +v;
    }
    get barBrush() {
        return brushToString(this.i.e1);
    }
    set barBrush(v) {
        this.i.e1 = stringToBrush(v);
    }
    get barOutline() {
        return brushToString(this.i.e2);
    }
    set barOutline(v) {
        this.i.e2 = stringToBrush(v);
    }
    get barStrokeThickness() {
        return this.i.a7;
    }
    set barStrokeThickness(v) {
        this.i.a7 = +v;
    }
    get rangeThumbBrush() {
        return brushToString(this.i.fj);
    }
    set rangeThumbBrush(v) {
        this.i.fj = stringToBrush(v);
    }
    get rangeThumbOutline() {
        return brushToString(this.i.fk);
    }
    set rangeThumbOutline(v) {
        this.i.fk = stringToBrush(v);
    }
    get rangeThumbStrokeThickness() {
        return this.i.bm;
    }
    set rangeThumbStrokeThickness(v) {
        this.i.bm = +v;
    }
    get rangeThumbRidgesBrush() {
        return brushToString(this.i.fl);
    }
    set rangeThumbRidgesBrush(v) {
        this.i.fl = stringToBrush(v);
    }
    get lowerCalloutBrush() {
        return brushToString(this.i.fb);
    }
    set lowerCalloutBrush(v) {
        this.i.fb = stringToBrush(v);
    }
    get lowerCalloutTextColor() {
        return brushToString(this.i.fd);
    }
    set lowerCalloutTextColor(v) {
        this.i.fd = stringToBrush(v);
    }
    get lowerCalloutOutline() {
        return brushToString(this.i.fc);
    }
    set lowerCalloutOutline(v) {
        this.i.fc = stringToBrush(v);
    }
    get lowerCalloutStrokeThickness() {
        return this.i.be;
    }
    set lowerCalloutStrokeThickness(v) {
        this.i.be = +v;
    }
    get higherCalloutBrush() {
        return brushToString(this.i.e3);
    }
    set higherCalloutBrush(v) {
        this.i.e3 = stringToBrush(v);
    }
    get higherCalloutTextColor() {
        return brushToString(this.i.e5);
    }
    set higherCalloutTextColor(v) {
        this.i.e5 = stringToBrush(v);
    }
    get higherCalloutOutline() {
        return brushToString(this.i.e4);
    }
    set higherCalloutOutline(v) {
        this.i.e4 = stringToBrush(v);
    }
    get higherCalloutStrokeThickness() {
        return this.i.a9;
    }
    set higherCalloutStrokeThickness(v) {
        this.i.a9 = +v;
    }
    get isCustomThumbProvided() {
        return this.i.ac;
    }
    get isCustomRangeThumbProvided() {
        return this.i.aa;
    }
    get isCustomBarProvided() {
        return this.i.z;
    }
    get isCustomShadeProvided() {
        return this.i.ab;
    }
    get areThumbCalloutsEnabled() {
        return this.i.r;
    }
    set areThumbCalloutsEnabled(v) {
        this.i.r = ensureBool(v);
    }
    get thumbCalloutTextStyle() {
        return this.i.o;
    }
    set thumbCalloutTextStyle(v) {
        this.i.o = v;
    }
    destroy() {
        this.i.destroy();
    }
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    flush() {
        this.i.c9();
    }
    trackDirty() {
        this.i.trackDirty();
    }
    get resolvingAxisValue() {
        if (this._resolvingAxisValue == null) {
            this._resolvingAxisValue = new EventEmitter();
            this.i.resolvingAxisValue = delegateCombine(this.i.resolvingAxisValue, (o, e) => {
                let outerArgs = new ZoomSliderResolvingAxisValueEventArgs();
                outerArgs._provideImplementation(e);
                this._resolvingAxisValue.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._resolvingAxisValue;
    }
    get windowRectChanged() {
        if (this._windowRectChanged == null) {
            this._windowRectChanged = new EventEmitter();
            this.i.windowRectChanged = delegateCombine(this.i.windowRectChanged, (o, e) => {
                let outerArgs = new RectChangedEventArgs();
                outerArgs._provideImplementation(e);
                this._windowRectChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._windowRectChanged;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxZoomSliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-zoom-slider',
                template: ``,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: IgxZoomSliderComponent_PROVIDERS,
                styles: [`
		:host {
			display: block;
		}
	`]
            },] },
];
/** @nocollapse */
IgxZoomSliderComponent.ctorParameters = () => [
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgZone, },
    { type: Injector, },
    { type: ComponentFactoryResolver, },
];
IgxZoomSliderComponent.propDecorators = {
    "height": [{ type: Input },],
    "width": [{ type: Input },],
    "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
    "panTransitionDuration": [{ type: Input },],
    "maxZoomWidth": [{ type: Input },],
    "pixelScalingRatio": [{ type: Input },],
    "actualPixelScalingRatio": [{ type: Input },],
    "windowRect": [{ type: Input },],
    "minZoomWidth": [{ type: Input },],
    "startInset": [{ type: Input },],
    "endInset": [{ type: Input },],
    "trackStartInset": [{ type: Input },],
    "trackEndInset": [{ type: Input },],
    "barExtent": [{ type: Input },],
    "orientation": [{ type: Input },],
    "lowerThumbBrush": [{ type: Input },],
    "lowerThumbStrokeThickness": [{ type: Input },],
    "higherThumbStrokeThickness": [{ type: Input },],
    "higherThumbBrush": [{ type: Input },],
    "lowerThumbOutline": [{ type: Input },],
    "higherThumbOutline": [{ type: Input },],
    "lowerThumbRidgesBrush": [{ type: Input },],
    "higherThumbRidgesBrush": [{ type: Input },],
    "lowerThumbWidth": [{ type: Input },],
    "higherThumbWidth": [{ type: Input },],
    "lowerThumbHeight": [{ type: Input },],
    "higherThumbHeight": [{ type: Input },],
    "lowerShadeBrush": [{ type: Input },],
    "lowerShadeOutline": [{ type: Input },],
    "lowerShadeStrokeThickness": [{ type: Input },],
    "higherShadeBrush": [{ type: Input },],
    "higherShadeOutline": [{ type: Input },],
    "higherShadeStrokeThickness": [{ type: Input },],
    "barBrush": [{ type: Input },],
    "barOutline": [{ type: Input },],
    "barStrokeThickness": [{ type: Input },],
    "rangeThumbBrush": [{ type: Input },],
    "rangeThumbOutline": [{ type: Input },],
    "rangeThumbStrokeThickness": [{ type: Input },],
    "rangeThumbRidgesBrush": [{ type: Input },],
    "lowerCalloutBrush": [{ type: Input },],
    "lowerCalloutTextColor": [{ type: Input },],
    "lowerCalloutOutline": [{ type: Input },],
    "lowerCalloutStrokeThickness": [{ type: Input },],
    "higherCalloutBrush": [{ type: Input },],
    "higherCalloutTextColor": [{ type: Input },],
    "higherCalloutOutline": [{ type: Input },],
    "higherCalloutStrokeThickness": [{ type: Input },],
    "areThumbCalloutsEnabled": [{ type: Input },],
    "thumbCalloutTextStyle": [{ type: Input },],
    "resolvingAxisValue": [{ type: Output },],
    "windowRectChanged": [{ type: Output },],
};
//# sourceMappingURL=igx-zoom-slider-component.js.map