import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from './igx-strategy-based-indicator-component';
import { IgxFinancialIndicatorComponent } from './igx-financial-indicator-component';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { ChaikinVolatilityIndicator } from "./ChaikinVolatilityIndicator";
/**
 * Represents a IgxDataChartComponent Chaikin Volatility indicator series.
 * The ChaikinVolatility indicator attempts to show volatility by displaying the spread between
 * the high and low values.
 * Default required members: High, Low
*/
export var IgxChaikinVolatilityIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }];
var IgxChaikinVolatilityIndicatorComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxChaikinVolatilityIndicatorComponent, _super);
    function IgxChaikinVolatilityIndicatorComponent() {
        return _super.call(this) || this;
    }
    IgxChaikinVolatilityIndicatorComponent.prototype.createImplementation = function () {
        return new ChaikinVolatilityIndicator();
    };
    Object.defineProperty(IgxChaikinVolatilityIndicatorComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxChaikinVolatilityIndicatorComponent.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current ChaikinVolatilityIndicator object.
         * The typical, and initial, value for ChaikinVolatilityIndicator periods is 10.
        *
        * Set the `period` property if you wish to change the moving average period for the indicator.
        *
        * ```html
        * <igx-data-chart [dataSource]="data">
        *   <igx-category-x-axis #xAxis
        *     label="time">
        *   </igx-category-x-axis>
        *   <igx-numeric-y-axis #yAxis>
        *   </igx-numeric-y-axis>
        *
        *   <igx-chaikin-volatility-indicator
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     openMemberPath="open"
        *     highMemberPath="high"
        *     lowMemberPath="low"
        *     closeMemberPath="close"
        *     volumeMemberPath="volume"
        *     period="30">
        *   </igx-chaikin-volatility-indicator>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the moving average period for the current ChaikinVolatilityIndicator object.
             * The typical, and initial, value for ChaikinVolatilityIndicator periods is 10.
            *
            * Set the `period` property if you wish to change the moving average period for the indicator.
            *
            * ```html
            * <igx-data-chart [dataSource]="data">
            *   <igx-category-x-axis #xAxis
            *     label="time">
            *   </igx-category-x-axis>
            *   <igx-numeric-y-axis #yAxis>
            *   </igx-numeric-y-axis>
            *
            *   <igx-chaikin-volatility-indicator
            *     [xAxis]="xAxis"
            *     [yAxis]="yAxis"
            *     openMemberPath="open"
            *     highMemberPath="high"
            *     lowMemberPath="low"
            *     closeMemberPath="close"
            *     volumeMemberPath="volume"
            *     period="30">
            *   </igx-chaikin-volatility-indicator>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.qa;
        },
        set: function (v) {
            this.i.qa = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgxChaikinVolatilityIndicatorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-chaikin-volatility-indicator',
                    template: "",
                    providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxChaikinVolatilityIndicatorComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxChaikinVolatilityIndicatorComponent.ctorParameters = function () { return []; };
    IgxChaikinVolatilityIndicatorComponent.propDecorators = {
        "period": [{ type: Input },],
    };
    return IgxChaikinVolatilityIndicatorComponent;
}(IgxStrategyBasedIndicatorComponent));
export { IgxChaikinVolatilityIndicatorComponent };
//# sourceMappingURL=igx-chaikin-volatility-indicator-component.js.map