import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IndicatorDisplayType, IndicatorDisplayType_$type } from './IndicatorDisplayType';
import { TrendLineType, TrendLineType_$type } from './TrendLineType';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { ensureEnum, brushToString, stringToBrush, toPoint, fromRect } from "./componentUtil";
/**
 * Represents the base functionality for a IgxDataChartComponent financial indicator series.
*/
export var IgxFinancialIndicatorComponent_PROVIDERS = [{ provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialIndicatorComponent; }) }];
var IgxFinancialIndicatorComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxFinancialIndicatorComponent, _super);
    function IgxFinancialIndicatorComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "displayType", {
        /**
         * Gets or sets the display for the current FinancialIndicator object.
        */
        get: /**
             * Gets or sets the display for the current FinancialIndicator object.
            */
        function () {
            return this.i.ox;
        },
        set: function (v) {
            this.i.ox = ensureEnum(IndicatorDisplayType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "ignoreFirst", {
        /**
         * Gets or sets the number of values to hide at the beginning of the indicator.
        */
        get: /**
             * Gets or sets the number of values to hide at the beginning of the indicator.
            */
        function () {
            return this.i.o3;
        },
        set: function (v) {
            this.i.o3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current indicator series.
        */
        get: /**
             * Gets or sets the trend type for the current indicator series.
            */
        function () {
            return this.i.trendLineType;
        },
        set: function (v) {
            this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush to use to draw the trend line.
        */
        get: /**
             * Gets or sets the brush to use to draw the trend line.
            */
        function () {
            return brushToString(this.i.trendLineBrush);
        },
        set: function (v) {
            this.i.trendLineBrush = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this indicator.
        */
        get: /**
             * Gets the effective TrendLineBrush for this indicator.
            */
        function () {
            return brushToString(this.i.pl);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current indicator object's trend line.
        */
        get: /**
             * Gets or sets the thickness of the current indicator object's trend line.
            */
        function () {
            return this.i.trendLineThickness;
        },
        set: function (v) {
            this.i.trendLineThickness = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialIndicatorComponent.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for trend line period is 7.
        */
        get: /**
             * Gets or sets the trend line period for the current series.
             * The typical, and initial, value for trend line period is 7.
            */
        function () {
            return this.i.trendLinePeriod;
        },
        set: function (v) {
            this.i.trendLinePeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    IgxFinancialIndicatorComponent.prototype.getSeriesValueBoundingBox = /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    function (world) {
        var iv = this.i.k9(toPoint(world));
        return fromRect(iv);
    };
    IgxFinancialIndicatorComponent.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ed(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialIndicatorComponent.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.e3(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgxFinancialIndicatorComponent.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.e1(toPoint(world), skipUnknowns);
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxFinancialIndicatorComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c5(item);
        return (iv);
    };
    IgxFinancialIndicatorComponent.propDecorators = {
        "displayType": [{ type: Input },],
        "ignoreFirst": [{ type: Input },],
        "trendLineType": [{ type: Input },],
        "trendLineBrush": [{ type: Input },],
        "trendLineThickness": [{ type: Input },],
        "trendLinePeriod": [{ type: Input },],
    };
    return IgxFinancialIndicatorComponent;
}(IgxFinancialSeriesComponent));
export { IgxFinancialIndicatorComponent };
//# sourceMappingURL=igx-financial-indicator-component.js.map