import { HighlightingState } from './HighlightingState';
import { IgxSeriesComponent } from './igx-series-component';
import { HighlightingInfo as HighlightingInfo_internal } from "./HighlightingInfo";
/**
 * Contains contextual information about a highlighting.
*
* You can use the `HighlightingInfo` to get the current series is a range type series.
*
* <!-- Angular JS -->
*
*      N/A
*
* <!-- Ignite JS -->
*
*      N/A
*/
export declare class HighlightingInfo {
    protected createImplementation(): HighlightingInfo_internal;
    protected _implementation: any;
    readonly i: HighlightingInfo_internal;
    private onImplementationCreated();
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The index of the first highlighted item.
    *
    * You can use `startIndex` to get or set the first highlighted item for the series.
    */
    startIndex: number;
    /**
     * The index of the last highlighted item.
    *
    * You can use the `endIndex` to get or set the last highlighted item for the series.
    */
    endIndex: number;
    /**
     * The state of the highlighting.
    *
    * You can use the `state` to get or set the transitioning state of the highlighting, between In, Out, or Static.
    */
    state: HighlightingState;
    /**
     * A number between 0 and 1 representing the progress of the highlighting.
    *
    * You can use the `progress` property to set a number between 0 and 1 representing the progress of the highlighting.
    */
    progress: number;
    /**
     * True if this HighlightingInfo represents a marker highlighting.
    *
    * You can set the `isMarker` to True if the HighlightingInfo represents a marker highlighting. Otherwise set to false.
    */
    isMarker: boolean;
    /**
     * The series in context.
    *
    * You can use the `series` property to get the series in context.
    */
    readonly series: IgxSeriesComponent;
}
