import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from './type';
import { LegendMouseButtonEventArgs } from './igx-legend-mouse-button-event-args';
import { LegendMouseEventArgs } from './igx-legend-mouse-event-args';
/**
 * Represents the base class for a legend in IgxDataChartComponent.
*/
export var IgxLegendBaseComponent_PROVIDERS = [];
var IgxLegendBaseComponent = /** @class */ (function () {
    function IgxLegendBaseComponent() {
        this._legendItemMouseLeftButtonDown = null;
        this._legendItemMouseLeftButtonUp = null;
        this._legendItemMouseEnter = null;
        this._legendItemMouseLeave = null;
        this._legendItemMouseMove = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxLegendBaseComponent.prototype.createImplementation = function () {
        return null;
    };
    IgxLegendBaseComponent.prototype.ngOnInit = function () {
    };
    Object.defineProperty(IgxLegendBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxLegendBaseComponent.prototype.onImplementationCreated = function () {
    };
    Object.defineProperty(IgxLegendBaseComponent.prototype, "legendItemMouseLeftButtonDown", {
        get: /**
             * Event raised when the left mouse button is pressed while the mouse pointer is over a legend item
             * in this Legend.
            */
        function () {
            var _this = this;
            if (this._legendItemMouseLeftButtonDown == null) {
                this._legendItemMouseLeftButtonDown = new EventEmitter();
                this.i.legendItemMouseLeftButtonDown = delegateCombine(this.i.legendItemMouseLeftButtonDown, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new LegendMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._legendItemMouseLeftButtonDown.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._legendItemMouseLeftButtonDown;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendBaseComponent.prototype, "legendItemMouseLeftButtonUp", {
        get: /**
             * Event raised when the left mouse button is released while the mouse pointer is over a legend item
             * in this Legend.
            */
        function () {
            var _this = this;
            if (this._legendItemMouseLeftButtonUp == null) {
                this._legendItemMouseLeftButtonUp = new EventEmitter();
                this.i.legendItemMouseLeftButtonUp = delegateCombine(this.i.legendItemMouseLeftButtonUp, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new LegendMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._legendItemMouseLeftButtonUp.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._legendItemMouseLeftButtonUp;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendBaseComponent.prototype, "legendItemMouseEnter", {
        get: /**
             * Event raised when the mouse pointer enters a legend item of this legend.
            */
        function () {
            var _this = this;
            if (this._legendItemMouseEnter == null) {
                this._legendItemMouseEnter = new EventEmitter();
                this.i.legendItemMouseEnter = delegateCombine(this.i.legendItemMouseEnter, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new LegendMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._legendItemMouseEnter.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._legendItemMouseEnter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendBaseComponent.prototype, "legendItemMouseLeave", {
        get: /**
             * Event raised when the mouse pointer leaves a legend item of this legend.
            */
        function () {
            var _this = this;
            if (this._legendItemMouseLeave == null) {
                this._legendItemMouseLeave = new EventEmitter();
                this.i.legendItemMouseLeave = delegateCombine(this.i.legendItemMouseLeave, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new LegendMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._legendItemMouseLeave.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._legendItemMouseLeave;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendBaseComponent.prototype, "legendItemMouseMove", {
        get: /**
             * Event raised when the mouse pointer moves over a legend item of this legend.
            */
        function () {
            var _this = this;
            if (this._legendItemMouseMove == null) {
                this._legendItemMouseMove = new EventEmitter();
                this.i.legendItemMouseMove = delegateCombine(this.i.legendItemMouseMove, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new LegendMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._legendItemMouseMove.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._legendItemMouseMove;
        },
        enumerable: true,
        configurable: true
    });
    IgxLegendBaseComponent.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    IgxLegendBaseComponent.propDecorators = {
        "legendItemMouseLeftButtonDown": [{ type: Output },],
        "legendItemMouseLeftButtonUp": [{ type: Output },],
        "legendItemMouseEnter": [{ type: Output },],
        "legendItemMouseLeave": [{ type: Output },],
        "legendItemMouseMove": [{ type: Output },],
    };
    return IgxLegendBaseComponent;
}());
export { IgxLegendBaseComponent };
//# sourceMappingURL=igx-legend-base-component.js.map