import * as tslib_1 from "tslib";
import { Component, Renderer2, ElementRef, Inject, forwardRef, Input, NgZone, ChangeDetectionStrategy } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { IgxLegendBaseComponent } from './igx-legend-base-component';
import { Legend } from "./Legend";
import { LegendOrientation, LegendOrientation_$type } from './LegendOrientation';
import { AngularRenderer } from './angular-renderer';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { ensureEnum } from './componentUtil';
export var IgxLegendComponent_PROVIDERS = [{ provide: IgxLegendBaseComponent, useExisting: forwardRef(function () { return IgxLegendComponent; }) }];
/**
 * Represents a legend in a IgxDataChartComponent control.
*
* The `IgxLegendComponent` helps end-user identify visuals of chart series with contextual information related to the data plotted in the chart control.
*
* ```html
* angular
* ```
*/
var IgxLegendComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxLegendComponent, _super);
    function IgxLegendComponent(renderer, elRef, document, ngZone) {
        var _this = _super.call(this) || this;
        _this.renderer = renderer;
        _this.elRef = elRef;
        _this.document = document;
        _this.ngZone = ngZone;
        _this._zoneRunner = function (act) { return _this.ngZone.run(act); };
        _this.container = renderer.createElement("div");
        renderer.appendChild(elRef.nativeElement, _this.container);
        var root;
        root = _this.container;
        if (_this.container != null) {
            root = _this.container;
        }
        var ren = new AngularRenderer(root, _this.renderer, _this.document, _this.ngZone, true, DataChartStylingDefaults);
        _this._wrapper = ren;
        _this.i.provideContainer(ren);
        return _this;
    }
    IgxLegendComponent.prototype.ngOnDestroy = function () {
        this._wrapper.destroy();
    };
    IgxLegendComponent.prototype.createImplementation = function () {
        return new Legend();
    };
    Object.defineProperty(IgxLegendComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendComponent.prototype, "orientation", {
        /**
     * Gets or sets the current Legend object's orientation.
    */
        get: /**
             * Gets or sets the current Legend object's orientation.
            */
        function () {
            return this.i.a9;
        },
        set: function (v) {
            this.i.a9 = ensureEnum(LegendOrientation_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendComponent.prototype, "textColor", {
        /**
         * Gets or sets color of text
        */
        get: /**
             * Gets or sets color of text
            */
        function () {
            return this.i.bf;
        },
        set: function (v) {
            this.i.bf = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLegendComponent.prototype, "textStyle", {
        /**
         * Gets or sets style of text.
        */
        get: /**
             * Gets or sets style of text.
            */
        function () {
            return this.i.bg;
        },
        set: function (v) {
            this.i.bg = v;
        },
        enumerable: true,
        configurable: true
    });
    IgxLegendComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-legend',
                    template: "",
                    providers: [{ provide: IgxLegendBaseComponent, useExisting: forwardRef(function () { return IgxLegendComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    styles: ["\n\t\t:host {\n\t\t\tdisplay: block;\n\t\t}\n\t"]
                },] },
    ];
    /** @nocollapse */
    IgxLegendComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: ElementRef, },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
        { type: NgZone, },
    ]; };
    IgxLegendComponent.propDecorators = {
        "orientation": [{ type: Input },],
        "textColor": [{ type: Input },],
        "textStyle": [{ type: Input },],
    };
    return IgxLegendComponent;
}(IgxLegendBaseComponent));
export { IgxLegendComponent };
//# sourceMappingURL=igx-legend-component.js.map