import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { UnknownValuePlotting, UnknownValuePlotting_$type } from './UnknownValuePlotting';
import { IgxHorizontalAnchoredCategorySeriesComponent } from './igx-horizontal-anchored-category-series-component';
import { IgxAnchoredCategorySeriesComponent } from './igx-anchored-category-series-component';
import { IgxCategorySeriesComponent } from './igx-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { LineSeries } from "./LineSeries";
import { ensureEnum } from "./componentUtil";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgxLineSeriesComponent` belongs to a group of `IgxLineSeriesComponent` and it is rendered using a collection of points connected by straight line segments.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
* ```
*/
export var IgxLineSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }];
var IgxLineSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxLineSeriesComponent, _super);
    function IgxLineSeriesComponent() {
        return _super.call(this) || this;
    }
    IgxLineSeriesComponent.prototype.createImplementation = function () {
        return new LineSeries();
    };
    Object.defineProperty(IgxLineSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLineSeriesComponent.prototype, "isAreaOrLine", {
        /**
         * Gets whether the current series shows an area or line shape.
        *
        * Gets whether the `IgxLineSeriesComponent` shows an area or a line shape.
        */
        get: /**
             * Gets whether the current series shows an area or line shape.
            *
            * Gets whether the `IgxLineSeriesComponent` shows an area or a line shape.
            */
        function () {
            return this.i.ci;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxLineSeriesComponent.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        *
        * Determines how unknown values will be plotted for the `IgxLineSeriesComponent`. This can be set to `IgxLineSeriesComponent` to create a continous shape or `IgxLineSeriesComponent` to create breaks in the series.
        *
        * Null and Double.NaN are two examples of unknown values.
        *
        * ```html
        * <igx-data-chart #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         unknownValuePlotting="LinearInterpolate">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Determines how unknown values will be plotted on the chart.
             * Null and Double.NaN are two examples of unknown values.
            *
            * Determines how unknown values will be plotted for the `IgxLineSeriesComponent`. This can be set to `IgxLineSeriesComponent` to create a continous shape or `IgxLineSeriesComponent` to create breaks in the series.
            *
            * Null and Double.NaN are two examples of unknown values.
            *
            * ```html
            * <igx-data-chart #chart
            *     [dataSource]="data">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         unknownValuePlotting="LinearInterpolate">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.unknownValuePlotting;
        },
        set: function (v) {
            this.i.unknownValuePlotting = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    IgxLineSeriesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-line-series',
                    template: "",
                    providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxLineSeriesComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxLineSeriesComponent.ctorParameters = function () { return []; };
    IgxLineSeriesComponent.propDecorators = {
        "unknownValuePlotting": [{ type: Input },],
    };
    return IgxLineSeriesComponent;
}(IgxHorizontalAnchoredCategorySeriesComponent));
export { IgxLineSeriesComponent };
//# sourceMappingURL=igx-line-series-component.js.map