import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxAxisComponent } from './igx-axis-component';
import { ensureBool } from "./componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent numeric axes.
*/
export var IgxNumericAxisBaseComponent_PROVIDERS = [{ provide: IgxAxisComponent, useExisting: forwardRef(function () { return IgxNumericAxisBaseComponent; }) }];
var IgxNumericAxisBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxNumericAxisBaseComponent, _super);
    function IgxNumericAxisBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "isNumeric", {
        /**
         * Gets or sets if the current axis is of numeric axis type
        */
        get: /**
             * Gets or sets if the current axis is of numeric axis type
            */
        function () {
            return this.i.b1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "minimumValue", {
        /**
         * Gets or sets the MinimumValue property.
        *
        * Used to set the minimum value of a numeric axis. To get the minimum value in effect on a numeric axis use `actualMinimumValue`.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         minimumValue=0
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the MinimumValue property.
            *
            * Used to set the minimum value of a numeric axis. To get the minimum value in effect on a numeric axis use `actualMinimumValue`.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         minimumValue=0
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.jo;
        },
        set: function (v) {
            this.i.jo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualMinimumValue", {
        /**
         * Gets the effective minimum value for the current numeric axis object.
        *
        * The `actualMinimumValue` is used to get the effective minimum value for a numeric axis.
        */
        get: /**
             * Gets the effective minimum value for the current numeric axis object.
            *
            * The `actualMinimumValue` is used to get the effective minimum value for a numeric axis.
            */
        function () {
            return this.i.jg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualVisibleMinimumValue", {
        /**
         * Gets the effective minimum value for the current numeric axis object.
        *
        * The `IgxNumericAxisBaseComponent` is used to get the current visible maximum value for the a numeric axis. Note, at times the `IgxNumericAxisBaseComponent` may differ from the `IgxNumericAxisBaseComponent`, for example when the chart is zoomed.
        */
        get: /**
             * Gets the effective minimum value for the current numeric axis object.
            *
            * The `IgxNumericAxisBaseComponent` is used to get the current visible maximum value for the a numeric axis. Note, at times the `IgxNumericAxisBaseComponent` may differ from the `IgxNumericAxisBaseComponent`, for example when the chart is zoomed.
            */
        function () {
            return this.i.jj;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "maximumValue", {
        /**
         * Gets or sets the MaximumValue property.
        *
        * Used to set the maximum value of a numeric axis. To get the maximum value in effect on a numeric axis use `actualMaximumValue`.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         maximumValue=80
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the MaximumValue property.
            *
            * Used to set the maximum value of a numeric axis. To get the maximum value in effect on a numeric axis use `actualMaximumValue`.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         maximumValue=80
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.jn;
        },
        set: function (v) {
            this.i.jn = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualMaximumValue", {
        /**
         * Gets the effective maximum value for the current numeric axis object.
        *
        * The `actualMaximumValue` is used to get the effective maximum value for a numeric axis.
        */
        get: /**
             * Gets the effective maximum value for the current numeric axis object.
            *
            * The `actualMaximumValue` is used to get the effective maximum value for a numeric axis.
            */
        function () {
            return this.i.jf;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualVisibleMaximumValue", {
        /**
         * Gets the effective visible maximum value for the current numeric axis object.
        *
        * The `actualVisibleMaximumValue` is used to get the current visible maximum value for the a numeric axis. Note, at times the `actualVisibleMaximumValue` may differ from the `actualMaximumValue`, for example when the chart is zoomed.
        */
        get: /**
             * Gets the effective visible maximum value for the current numeric axis object.
            *
            * The `actualVisibleMaximumValue` is used to get the current visible maximum value for the a numeric axis. Note, at times the `actualVisibleMaximumValue` may differ from the `actualMaximumValue`, for example when the chart is zoomed.
            */
        function () {
            return this.i.ji;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "interval", {
        /**
         * Gets or sets the Interval property.
        *
        * The `interval` is used to get or set the numeric axis major interval which specifies how frequent major gridlines and axis labels are rendered on an axis.
        *
        * ```html
        * <igx-data-chart
        *       [dataSource]="data">
        *       <igx-category-x-axis
        *         label="label"
        *         #xAxis
        *         >
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis
        *         interval="20"
        *         #yAxis>
        *       </igx-numeric-y-axis>
        *
        *       <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *       </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the Interval property.
            *
            * The `interval` is used to get or set the numeric axis major interval which specifies how frequent major gridlines and axis labels are rendered on an axis.
            *
            * ```html
            * <igx-data-chart
            *       [dataSource]="data">
            *       <igx-category-x-axis
            *         label="label"
            *         #xAxis
            *         >
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis
            *         interval="20"
            *         #yAxis>
            *       </igx-numeric-y-axis>
            *
            *       <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *       </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.jk;
        },
        set: function (v) {
            this.i.jk = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        *
        * The `actualInterval` is used to get the effective value for the current Interval of a numeric axis.
        */
        get: /**
             * Gets the effective value for the current Interval.
            *
            * The `actualInterval` is used to get the effective value for the current Interval of a numeric axis.
            */
        function () {
            return this.i.je;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "minorInterval", {
        /**
         * Gets or sets the MinorInterval property.
        *
        * The `minorInterval` is used to get or set the numeric axis minor interval which specifies how frequent minor gridlines are rendered on an axis. Please note, in order for minor gridlines to be displayed the following may also need to be set: `IgxNumericAxisBaseComponent`, `IgxNumericAxisBaseComponent`.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data" >
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         minorInterval= 2.5
        *         minorStroke="blue"
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the MinorInterval property.
            *
            * The `minorInterval` is used to get or set the numeric axis minor interval which specifies how frequent minor gridlines are rendered on an axis. Please note, in order for minor gridlines to be displayed the following may also need to be set: `IgxNumericAxisBaseComponent`, `IgxNumericAxisBaseComponent`.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data" >
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         minorInterval= 2.5
            *         minorStroke="blue"
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.jp;
        },
        set: function (v) {
            this.i.jp = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        *
        * The `actualMinorInterval` is used to get the effective minor interval for a numeric axis.
        */
        get: /**
             * Gets the effective value for the current MinorInterval.
            *
            * The `actualMinorInterval` is used to get the effective minor interval for a numeric axis.
            */
        function () {
            return this.i.jh;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "referenceValue", {
        /**
         * Gets or sets the ReferenceValue property.
        *
        * Used to get or set a reference value on a numeric axis which when used with an area, bar, or column series will result in the series shapes being drawn above or below the specified value.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         referenceValue=30
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the ReferenceValue property.
            *
            * Used to get or set a reference value on a numeric axis which when used with an area, bar, or column series will result in the series shapes being drawn above or below the specified value.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         referenceValue=30
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.jq;
        },
        set: function (v) {
            this.i.jq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "isLogarithmic", {
        /**
         * Gets or sets the IsLogarithmic property.
        *
        * `isLogarithmic` is used to get or set whether the numeric axis scaler is in linear or logarithmic mode. For logarithmic scaling, this can be used in conjunction with `logarithmBase` to further define the logarithmic scale.
        *
        * ```html
        * <igx-data-chart
        *       [dataSource]="data">
        *       <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis
        *         isLogarithmic=true
        *         logarithmBase=2
        *         #yAxis>
        *       </igx-numeric-y-axis>
        *       <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *       </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the IsLogarithmic property.
            *
            * `isLogarithmic` is used to get or set whether the numeric axis scaler is in linear or logarithmic mode. For logarithmic scaling, this can be used in conjunction with `logarithmBase` to further define the logarithmic scale.
            *
            * ```html
            * <igx-data-chart
            *       [dataSource]="data">
            *       <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis
            *         isLogarithmic=true
            *         logarithmBase=2
            *         #yAxis>
            *       </igx-numeric-y-axis>
            *       <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *       </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.i5;
        },
        set: function (v) {
            this.i.i5 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "actualIsLogarithmic", {
        /**
         * Determines if the axis has a valid logarithmic scale.
        *
        * Determines if the axis has a valid logarithmic scale.
        */
        get: /**
             * Determines if the axis has a valid logarithmic scale.
            *
            * Determines if the axis has a valid logarithmic scale.
            */
        function () {
            return this.i.i1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "logarithmBase", {
        /**
         * Gets or sets the LogarithmBase property.
        *
        * `logarithmBase` is used to get or set logarithm base when a numeric axis is in Logarithmic scale mode. For logarithmic scaling, this is used in conjunction with `isLogarithmic` or `IgxNumericAxisBaseComponent` to set logarithmic scaling.
        *
        * ```html
        * <igx-data-chart
        *       [dataSource]="data">
        *       <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis
        *         scaleMode="Logarithmic"
        *         logarithmBase=2
        *         #yAxis>
        *       </igx-numeric-y-axis>
        *       <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *       </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the LogarithmBase property.
            *
            * `logarithmBase` is used to get or set logarithm base when a numeric axis is in Logarithmic scale mode. For logarithmic scaling, this is used in conjunction with `isLogarithmic` or `IgxNumericAxisBaseComponent` to set logarithmic scaling.
            *
            * ```html
            * <igx-data-chart
            *       [dataSource]="data">
            *       <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis
            *         scaleMode="Logarithmic"
            *         logarithmBase=2
            *         #yAxis>
            *       </igx-numeric-y-axis>
            *       <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *       </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.js;
        },
        set: function (v) {
            this.i.js = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "hasUserMinimum", {
        /**
         * Determines if the axis has a user-defined minimum.
        *
        *  `hasUserMaximum` is used to determine if a numeric axis has a user definied maximum value.
        */
        get: /**
             * Determines if the axis has a user-defined minimum.
            *
            *  `hasUserMaximum` is used to determine if a numeric axis has a user definied maximum value.
            */
        function () {
            return this.i.i4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "hasUserMaximum", {
        /**
         * Determines if the axis has a user-defined maximum.
        *
        *  `hasUserMinimum` is used to determine if a numeric axis has a user definied minium value.
        */
        get: /**
             * Determines if the axis has a user-defined maximum.
            *
            *  `hasUserMinimum` is used to determine if a numeric axis has a user definied minium value.
            */
        function () {
            return this.i.i3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxNumericAxisBaseComponent.prototype, "abbreviateLargeNumbers", {
        get: function () {
            return this.i.i0;
        },
        set: function (v) {
            this.i.i0 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Unscales a value from screen space into axis space.
    
    * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
    *
    * Unscales a value from screen space into axis space.
    */
    /**
         * Unscales a value from screen space into axis space.
        
        * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
        *
        * Unscales a value from screen space into axis space.
        */
    IgxNumericAxisBaseComponent.prototype.unscaleValue = /**
         * Unscales a value from screen space into axis space.
        
        * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
        *
        * Unscales a value from screen space into axis space.
        */
    function (unscaledValue) {
        var iv = this.i.jr(unscaledValue);
        return (iv);
    };
    IgxNumericAxisBaseComponent.propDecorators = {
        "minimumValue": [{ type: Input },],
        "maximumValue": [{ type: Input },],
        "interval": [{ type: Input },],
        "minorInterval": [{ type: Input },],
        "referenceValue": [{ type: Input },],
        "isLogarithmic": [{ type: Input },],
        "logarithmBase": [{ type: Input },],
        "abbreviateLargeNumbers": [{ type: Input },],
    };
    return IgxNumericAxisBaseComponent;
}(IgxAxisComponent));
export { IgxNumericAxisBaseComponent };
//# sourceMappingURL=igx-numeric-axis-base-component.js.map