import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from './igx-strategy-based-indicator-component';
import { IgxFinancialIndicatorComponent } from './igx-financial-indicator-component';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { PercentageVolumeOscillatorIndicator } from "./PercentageVolumeOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Percentage Volume Oscillator (PVO) series.
 * Default required members: Volume
*
* You can use the `IgxPercentageVolumeOscillatorIndicatorComponent` to show the percentage difference volume.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-percentage-volume-oscillator-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-percentage-volume-oscillator-indicator>
* </igx-data-chart>
* ```
*/
export var IgxPercentageVolumeOscillatorIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }];
var IgxPercentageVolumeOscillatorIndicatorComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxPercentageVolumeOscillatorIndicatorComponent, _super);
    function IgxPercentageVolumeOscillatorIndicatorComponent() {
        return _super.call(this) || this;
    }
    IgxPercentageVolumeOscillatorIndicatorComponent.prototype.createImplementation = function () {
        return new PercentageVolumeOscillatorIndicator();
    };
    Object.defineProperty(IgxPercentageVolumeOscillatorIndicatorComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPercentageVolumeOscillatorIndicatorComponent.prototype, "shortPeriod", {
        /**
         * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
         * The typical, and initial, value for short PVO periods is 10.
        *
        * You can use the `shortPeriod` to set the short moving average period.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data" >
        *     <igx-category-x-axis
        * 		label="label"
        * 		#xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        * 		#yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-percentage-volume-oscillator-indicator
        * 		#series
        * 		[xAxis]="xAxis"
        * 		[yAxis]="yAxis"
        * 		openMemberPath="open"
        * 		highMemberPath="high"
        * 		lowMemberPath="low"
        * 		closeMemberPath="close"
        * 		shortPeriod="10">
        *     </igx-percentage-volume-oscillator-indicator>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
             * The typical, and initial, value for short PVO periods is 10.
            *
            * You can use the `shortPeriod` to set the short moving average period.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data" >
            *     <igx-category-x-axis
            * 		label="label"
            * 		#xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            * 		#yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-percentage-volume-oscillator-indicator
            * 		#series
            * 		[xAxis]="xAxis"
            * 		[yAxis]="yAxis"
            * 		openMemberPath="open"
            * 		highMemberPath="high"
            * 		lowMemberPath="low"
            * 		closeMemberPath="close"
            * 		shortPeriod="10">
            *     </igx-percentage-volume-oscillator-indicator>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.shortPeriod;
        },
        set: function (v) {
            this.i.shortPeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPercentageVolumeOscillatorIndicatorComponent.prototype, "longPeriod", {
        /**
         * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
         * The typical, and initial, value for long PVO periods is 30.
        *
        * You can use the `longPeriod` to set the long moving average period.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data" >
        *     <igx-category-x-axis
        * 		label="label"
        * 		#xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        * 		#yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-percentage-volume-oscillator-indicator
        * 		#series
        * 		[xAxis]="xAxis"
        * 		[yAxis]="yAxis"
        * 		openMemberPath="open"
        * 		highMemberPath="high"
        * 		lowMemberPath="low"
        * 		closeMemberPath="close"
        * 		longPeriod="30">
        *     </igx-percentage-volume-oscillator-indicator>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the short moving average period for the current PercentageVolumeOscillatorIndicator object.
             * The typical, and initial, value for long PVO periods is 30.
            *
            * You can use the `longPeriod` to set the long moving average period.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data" >
            *     <igx-category-x-axis
            * 		label="label"
            * 		#xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            * 		#yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-percentage-volume-oscillator-indicator
            * 		#series
            * 		[xAxis]="xAxis"
            * 		[yAxis]="yAxis"
            * 		openMemberPath="open"
            * 		highMemberPath="high"
            * 		lowMemberPath="low"
            * 		closeMemberPath="close"
            * 		longPeriod="30">
            *     </igx-percentage-volume-oscillator-indicator>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.longPeriod;
        },
        set: function (v) {
            this.i.longPeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgxPercentageVolumeOscillatorIndicatorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-percentage-volume-oscillator-indicator',
                    template: "",
                    providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxPercentageVolumeOscillatorIndicatorComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxPercentageVolumeOscillatorIndicatorComponent.ctorParameters = function () { return []; };
    IgxPercentageVolumeOscillatorIndicatorComponent.propDecorators = {
        "shortPeriod": [{ type: Input },],
        "longPeriod": [{ type: Input },],
    };
    return IgxPercentageVolumeOscillatorIndicatorComponent;
}(IgxStrategyBasedIndicatorComponent));
export { IgxPercentageVolumeOscillatorIndicatorComponent };
//# sourceMappingURL=igx-percentage-volume-oscillator-indicator-component.js.map