import { Type } from '@angular/core';
import { IgxPoint } from './IgxPoint';
import { IgxFinancialOverlayComponent } from './igx-financial-overlay-component';
import { IgxFinancialSeriesComponent } from './igx-financial-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { PriceChannelOverlay } from "./PriceChannelOverlay";
/**
 * Represents a IgxDataChartComponent Financial Price Channel Overlay series.
 * Default required members: High, Low
*
* You can use the `IgxPriceChannelOverlayComponent` to display price volatility.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-price-channel-overlay
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-price-channel-overlay>
* </igx-data-chart>
* ```
*/
export declare const IgxPriceChannelOverlayComponent_PROVIDERS: ({
    provide: typeof IgxFinancialSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxPriceChannelOverlayComponent extends IgxFinancialOverlayComponent {
    protected createImplementation(): PriceChannelOverlay;
    readonly i: PriceChannelOverlay;
    constructor();
    /**
     * Gets or sets the moving average period for the current PriceChannelOverlay object.
     * The typical, and initial, value for Bollinger band periods is 14.
    *
    * You can use the `period` to set the moving average.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-price-channel-overlay
    * 		#series
    * 		[xAxis]="xAxis"
    * 		[yAxis]="yAxis"
    * 		openMemberPath="open"
    * 		highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		period="14">
    *     </igx-price-channel-overlay>
    * </igx-data-chart>
    * ```
    */
    period: number;
    getSeriesValue(world: IgxPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgxPoint, skipUnknowns: boolean): number;
}
